%define courier_confdir	/etc/courier-imap
%define courier_datadir	%_datadir/courier-imap

%define confldap maildrop-ldap.conf
%define confmysql maildrop-mysql.conf


Name: maildrop
Version: 1.6.2
Release: alt1

Summary: maildrop mail filter/mail delivery agent
License: GPL
Group: Networking/Mail
Url: http://www.flounder.net/~mrsam/maildrop

Source0: %url/%name-%version.tar.bz2
Source1: %name.README-ALT
Source2: userdb.maildrop

# Fix some install paths
Patch0: %name-1.5.1-alt-makefile.patch

# remove references to mail_status from code
# because checks for this field was not implemented
#
# some mysql fixes by Egor Cheshkov <egor@iplus.ru>:
#  - possibility of using witespaces in the configure stanzas
#  - right code for use default UID/GID
#  - fix for handling 'where_clause' stanza
Patch1: %name-1.6.2-alt-mysqlfixes.patch

# ldap driver fixes by Victor Grischenko <gritzko@post.dcn.ru>
#  - possibility of using witespaces in the configure stanzas
#    (Base DN with witespaces, for example.)
Patch2: %name-1.6.2-alt-ldapfixes.patch

# some configs cleanup
Patch3: %name-1.4.0-alt-config.patch

# Change name of USERDB database from userdb.dat to userdb.db
Patch4: %name-1.5.3-alt-userdb.patch

# compile warnings cleanup
Patch5: %name-1.5.2-alt-warnings.patch

Prefix: %prefix

# Automatically added by buildreq on Fri Oct 03 2003
BuildRequires: gcc-c++ libMySQL-devel libdb4.0-devel libfam-devel libldap-devel
BuildRequires: libsasl2 libssl libstdc++-devel zlib-devel

%description
Maildrop - mail delivery agent with filtering capabilities and
Maildir/Mailbox format support.

%package common
Summary: maildrop mail filtering/delivery agent - common files
Group: Networking/Mail

%description common
Maildrop is a combination mail filter/mail delivery agent.
Maildrop reads the message to be delivered to your mailbox,
optionally reads instructions from a file how filter incoming
mail, then based on these instructions may deliver mail to an
alternate mailbox, or forward it, instead of dropping the
message into your mailbox.

Maildrop uses a structured, real, meta-programming language in
order to define filtering instructions.  Its basic features are
fast and efficient.  At sites which carry a light load, the
more advanced, CPU-demanding, features can be used to build
very sophisticated mail filters.  Maildrop deployments have
been reported at sites that support as many as 30,000
mailboxes.

%package utils
Summary: maildrop mail filter/mail delivery agent - utilities
Group: Networking/Mail
Provides: courier-common-utils
Conflicts: courier-imap-utils
Requires: %name-common = %version-%release

%description utils
Some common utilities for maildrop packages.

%package userdb
Summary: maildrop mail filter/mail delivery agent with USERDB support
Group: Networking/Mail
Provides: MDA, maildrop
Requires: %name-common = %version-%release, courier-common-utils

%description userdb
The %name package contains the maildrop MDA with USERDB support.
BerkleyDB database is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package ldap
Summary: maildrop mail filter/mail delivery agent with LDAP support
Group: Networking/Mail
Provides: MDA, maildrop
Requires: %name-common = %version-%release, courier-common-utils

%description ldap
The %name package contains the maildrop MDA with LDAP support.
LDAP tree is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package mysql
Summary: maildrop mail filter/mail delivery agent with MySQL support
Group: Networking/Mail
Provides: MDA, maildrop
Requires: %name-common = %version-%release, courier-common-utils

%description mysql
The %name package contains the maildrop MDA with MySQL support.
MySQL database is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package devel-static
Summary: RFC822 and RFC 2045 parsing libraries and headers files.
Group: Development/Other
#Requires: %name-common = %version-%release

%description devel-static
The %name package contains the libraries and header files for
parsing MIME (RFC2045) and e-mail messages (RFC822).

%package doc
Summary: documentation about the maildrop MDA
Group: Networking/Mail

%description doc
The %name packages contains the documentation about maildrop MDA.

%prep
%setup
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-maildropldap \
  --with-ldapconfig=%courier_confdir/%confldap \
  --without-db \
  --disable-userdb

%make_build

pushd maildrop
    %__mv maildrop maildrop-ldap
popd
%__make clean

%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-maildropmysql \
  --with-mysqlconfig=%courier_confdir/%confmysql \
  --without-db \
  --disable-userdb

%make_build

pushd maildrop
    %__mv maildrop maildrop-mysql
popd
%__make clean

%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-userdb \
  --with-db=db \
  --with-devel

%make_build

pushd maildrop
    %__mv maildrop maildrop-userdb
popd

%install

# prepare dest. directory-tree
%__mkdir_p %buildroot/%courier_confdir
%__mkdir_p %buildroot/%_docdir/%name-%version/html
%__mkdir_p %buildroot/%_docdir/%name-%version/maildir

%__make DESTDIR=%buildroot install

# install different versions of maildrop
%__install -D -m 0755 maildrop/maildrop-userdb %buildroot/%_bindir/maildrop-userdb
%__install -D -m 0755 maildrop/maildrop-ldap   %buildroot/%_bindir/maildrop-ldap
%__install -D -m 0755 maildrop/maildrop-mysql  %buildroot/%_bindir/maildrop-mysql

# install symlinks for some useful utilities
pushd %buildroot/%_sbindir
	%__ln_s ../share/courier-imap/makeuserdb makeuserdb
	%__ln_s ../share/courier-imap/userdb userdb
popd

# install additional binaries
%__install -m 0755 maildir/maildirkw   %buildroot/%_bindir
%__install -m 0644 maildir/maildirkw.1 %buildroot/%_man1dir

# install config-files
%__install -D -m 0644 %SOURCE2 %buildroot/%courier_confdir/userdb
%__install -D -m 0644 maildir/quotawarnmsg %buildroot/%courier_confdir/quotawarnmsg.example
%__install -D -m 0644 maildropldap.config  %buildroot/%courier_confdir/%confldap
%__install -D -m 0644 maildropmysql.config %buildroot/%courier_confdir/%confmysql

pushd %buildroot/%_man1dir
	%__ln_s maildrop.1 maildrop-userdb.1
	%__ln_s maildrop.1 maildrop-ldap.1
	%__ln_s maildrop.1 maildrop-mysql.1
popd

# adjust documentation 
#mv $RPM_BUILD_ROOT%_datadir/%name/html $RPM_BUILD_ROOT%_docdir/%name-%version
%__rm -rf %buildroot/%_datadir/%name/html

# maildir docs
%__install -m 0644 maildir/README.*.txt   %buildroot/%_docdir/%name-%version/maildir
%__install -m 0644 maildir/README.*.html  %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildir/maildirkw.html %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildir/AUTHORS %buildroot/%_docdir/%name-%version/maildir
%__install -m 0644 maildir/INSTALL %buildroot/%_docdir/%name-%version/maildir

# maildrop docs
%__install -m 0644 maildrop/README.html         %buildroot/%_docdir/%name-%version/html/README.maildrop.html
%__install -m 0644 maildrop/mailbot.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/maildropex.html     %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/maildropfilter.html %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/maildropgdbm.html   %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/maildrop.html       %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/maildroptips.html   %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/makedat.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop/reformail.html      %buildroot/%_docdir/%name-%version/html

%__install -m 0644 maildrop/maildrop.lsm        %buildroot/%_docdir/%name-%version

# rfc2045 docs
%__install -m 0644 rfc2045/makemime.html  %buildroot/%_docdir/%name-%version/html
%__install -m 0644 rfc2045/reformime.html %buildroot/%_docdir/%name-%version/html
%__install -m 0644 rfc2045/rfc2045.html   %buildroot/%_docdir/%name-%version/html

# rfc822 docs
%__install -m 0644 rfc822/ChangeLog   %buildroot/%_docdir/%name-%version/ChangeLog.rfc822
%__install -m 0644 rfc822/rfc822.html %buildroot/%_docdir/%name-%version/html

# userdb docs
%__install -m 0644 userdb/makeuserdb.html %buildroot/%_docdir/%name-%version/html
%__install -m 0644 userdb/userdb.html     %buildroot/%_docdir/%name-%version/html
%__install -m 0644 userdb/userdbpw.html   %buildroot/%_docdir/%name-%version/html

# src_root docs
%__install -m 0644 AUTHORS   %buildroot/%_docdir/%name-%version
%__install -m 0644 ChangeLog %buildroot/%_docdir/%name-%version
%__install -m 0644 COPYING   %buildroot/%_docdir/%name-%version
%__install -m 0644 INSTALL   %buildroot/%_docdir/%name-%version
%__install -m 0644 NEWS      %buildroot/%_docdir/%name-%version
%__install -m 0644 README    %buildroot/%_docdir/%name-%version
%__install -m 0644 UPGRADE   %buildroot/%_docdir/%name-%version
%__install -m 0644 maildroptips.txt %buildroot/%_docdir/%name-%version
%__install -m 0644 README.postfix   %buildroot/%_docdir/%name-%version

%__install -m 0644 INSTALL.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 README.html         %buildroot/%_docdir/%name-%version/html
%__install -m 0644 UPGRADE.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 deliverquota.html   %buildroot/%_docdir/%name-%version/html
%__install -m 0644 lockmail.html       %buildroot/%_docdir/%name-%version/html
%__install -m 0644 mailbot.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildirmake.html    %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildirquota.html   %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildropex.html     %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildropfilter.html %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildropgdbm.html   %buildroot/%_docdir/%name-%version/html
%__install -m 0644 maildrop.html       %buildroot/%_docdir/%name-%version/html
%__install -m 0644 makedat.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 makemime.html       %buildroot/%_docdir/%name-%version/html
%__install -m 0644 makeuserdb.html     %buildroot/%_docdir/%name-%version/html
%__install -m 0644 reformail.html      %buildroot/%_docdir/%name-%version/html
%__install -m 0644 reformime.html      %buildroot/%_docdir/%name-%version/html
%__install -m 0644 rfc2045.html        %buildroot/%_docdir/%name-%version/html
%__install -m 0644 rfc822.html         %buildroot/%_docdir/%name-%version/html
%__install -m 0644 userdb.html         %buildroot/%_docdir/%name-%version/html
%__install -m 0644 userdbpw.html       %buildroot/%_docdir/%name-%version/html

%__install -m 0644 %SOURCE1 %buildroot/%_docdir/%name-%version

%files common
#_bindir/maildrop-overbloat
%_bindir/lockmail
%_bindir/mailbot
%_bindir/makemime
%_bindir/reformail
%_bindir/reformime
%_mandir/man1/lockmail.1*
%_mandir/man1/mailbot.1*
%_mandir/man1/maildrop.1*
%_mandir/man1/makemime.1*
%_mandir/man1/reformail.1*
%_mandir/man1/reformime.1*
%_mandir/man5/*
%_mandir/man7/*

%files userdb
%dir %courier_confdir
%config %courier_confdir/userdb
%_bindir/maildrop-userdb
%_mandir/man1/maildrop-userdb.1*
%_mandir/man1/makedat.1*
%dir %courier_datadir
%courier_datadir/makedat

%files ldap
%dir %courier_confdir
%config %courier_confdir/%confldap
%_bindir/maildrop-ldap
%_mandir/man1/maildrop-ldap.1*

%files mysql
%dir %courier_confdir
%config %courier_confdir/%confmysql
%_bindir/maildrop-mysql
%_mandir/man1/maildrop-mysql.1*

%files devel-static
%_includedir/rfc822.h
%_includedir/rfc2045.h
%_includedir/rfc2047.h
%_libdir/librfc822.a
%_libdir/librfc2045.a
%_mandir/man3/*

%files utils
# utils for maildir
%dir %courier_confdir
%config %courier_confdir/quotawarnmsg.example
%_bindir/maildirmake
%_bindir/maildirkw
%_sbindir/deliverquota
%_sbindir/makeuserdb
%_sbindir/userdb
%_sbindir/userdbpw
%_mandir/man1/maildirmake.1*
%_mandir/man1/maildirkw.1*
%_mandir/man8/deliverquota.8*
# utils for userdb feature
%_mandir/man8/makeuserdb.8*
%_mandir/man8/pw2userdb.8*
%_mandir/man8/userdb.8*
%_mandir/man8/userdbpw.8*
%_mandir/man8/vchkpw2userdb.8*
%dir %courier_datadir
%courier_datadir/makedatprog
%courier_datadir/makeuserdb
%courier_datadir/pw2userdb
%courier_datadir/userdb
%courier_datadir/vchkpw2userdb

%files doc
%dir %_docdir/%name-%version
%_docdir/%name-%version/*

%changelog
* Fri Oct 03 2003 Dmitry Lebkov <dlebkov@altlinux.ru> 1.6.2-alt1
- 1.6.2
- spec-file cleanup
- maildrop-mysql:
  + possible memory corruption while reading config file fixed
- maildrop-ldap:
  + possibility of using witespaces in the configure stanzas
    (base DN with witespaces, for example)

* Thu May 15 2003 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.3-alt1
- 1.5.3

* Mon Mar 31 2003 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.2-alt1
- 1.5.2
- add 'Provides: MDA, maildrop' (bug #2413)

* Fri Jan 03 2003 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.1-alt1
- 1.5.1
- spec-file fixes

* Mon Nov 18 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.0-alt2
- fix USERDB database names in the makeuserdb and related docs.

* Fri Oct 25 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.0-alt1
- 1.5.0
- some spec-file fixes

* Mon Oct 14 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.4.0-alt2
- some fixes in the mysql driver code.

* Wed Sep 11 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.4.0-alt1
- initial package for ALT Linux
